import createFeatures
import pandas as pd
import glob
import os
import matplotlib.pyplot as plt
import helpers

def df_per_medium(file):
    list = createFeatures.createFeatureList(file)
    df = pd.DataFrame(list)
    df.columns = ['sen1', 'sen2', 'werther[]', 'medium', 'title' ,'link']
    return df

def getDiagramWithSen1(folder):
    """
    Plots diagram with
    x = days of the week;
    y = mean of sentiment per day;
    a line for every medium
    Prints a list with the number of analyzed articles per day
    :param folder with mutliple files of website downloads
    :return: diagram as png
    """
    files = sorted(glob.glob(os.path.join(folder, "*.csv")))
    dfDict = {}
    x = [] # number of days
    number_of_articles_per_day = []
    list_of_suicide_articles = []
    i = 1 #counter for the days of the week / number of files in folder
    j = 0

    for file in files:
        df = df_per_medium(file)
        list_of_suicide_articles.append(helpers.getArticlesWithSuicide(df.values.tolist())) # check if suicide reporting is found
        df_mean = df.groupby('medium').sen1.mean()
        number_of_articles_per_day.append(df['medium'].count())
        dfDict[i] = df_mean
        x.append(j)
        i += 1
        j += 1

    print("number_of_articles_per_day: ",number_of_articles_per_day)
    print("list_of_suicide_articles: ",list_of_suicide_articles)
    df_mean = pd.DataFrame(dfDict)
    lists = df_mean.reset_index().values.tolist()

    for l in lists:
        plt.plot(l[1:], label=l[0])

    plt.xticks(x)
    plt.ylim(25, 60) # scale of y

    plt.legend(ncol=3) #legend with 3 columns
    plt.savefig('./mean_sen_for_week.png')

    return plt.show()

###################  TEST   ########################
#folder = "./Artikel_fuer_eine_Woche (klein)"
#getDiagramWithSen1(folder)
####################################################

#def getDiagramForADay(file):
#    df = df_per_medium(file)
#    df.groupby('medium').sen1.mean()
#
#    myplot = df.plot(kind='bar')
#    myplot.set_xlabel("Medium")
#    myplot.set_ylabel("Sentiment")
#    myplot.set_ybound(0, 100)
#    return myplot

###################  TEST   ########################
#file = "./testfiles/positive_artikel_glueck.csv"
#print(getDiagramForADay(file))


